.. x.phs1903 documentation master file, created by
   sphinx-quickstart on Tue Oct 28 12:43:26 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###########################
 Code de base pour PHS1903
###########################

.. include:: ../../README.rst

.. toctree::
	:maxdepth: 2
	:caption: Table des matières

	self
	python
	arduino
	license
	glos
